requiresAuthorization property

bool get requiresAuthorization

Private and presence channels are the ones needing a signature from the application before Thoth will let a socket subscribe.

Implementation

bool get requiresAuthorization =>
    channel.startsWith('private-') || channel.startsWith('presence-');