client property
Authorizes private channels and supplies the credentials to do it with. Only public channels work without one.
Implementation
final HorusClient? client;
Authorizes private channels and supplies the credentials to do it with. Only public channels work without one.
final HorusClient? client;