onAuthFailure property
Called once when authorization is refused, before one retry — the hook for refreshing an expired token. Returning normally means "try again".
Implementation
final Future<void> Function()? onAuthFailure;
Called once when authorization is refused, before one retry — the hook for refreshing an expired token. Returning normally means "try again".
final Future<void> Function()? onAuthFailure;